@@ -1,6 +1,6 @@
 package MooX::Keyword::Chain;
 use 5.006; use strict; use warnings;
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 use Moo; our %CHAINS;
 use MooX::Keyword {
 	chain => {
@@ -31,7 +31,7 @@ MooX::Keyword::Chain - Subroutine chains
 
 =head1 VERSION
 
-Version 1.00
+Version 1.01
 
 =cut
 
@@ -116,16 +116,12 @@ You can find documentation for this module with the perldoc command.
 
 You can also look for information at:
 
-=over 4
+=over 2
 
 =item * RT: CPAN's request tracker (report bugs here)
 
 L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=MooX-Keyword-Chain>
 
-=item * CPAN Ratings
-
-L<https://cpanratings.perl.org/d/MooX-Keyword-Chain>
-
 =item * Search CPAN
 
 L<https://metacpan.org/release/MooX-Keyword-Chain>
@@ -136,7 +132,7 @@ L<https://metacpan.org/release/MooX-Keyword-Chain>
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is Copyright (c) 2023 by LNATION.
+This software is Copyright (c) 2023->2025 by LNATION.
 
 This is free software, licensed under:
 
